@@ -1,15 +1,13 @@
 #
 # Net::Dict.pm
 #
-# Copyright (C) 2001-2002 Neil Bowers <neil@bowers.com>
+# Copyright (C) 2001-2003 Neil Bowers <neil@bowers.com>
 # Copyright (c) 1998 Dmitry Rubinstein <dimrub@wisdom.weizmann.ac.il>.
 #
 # All rights reserved.  This program is free software; you can
 # redistribute it and/or modify it under the same terms as Perl
 # itself.
 #
-# $Id: Dict.pm,v 2.6 2002/03/24 00:41:55 neilb Exp $
-#
 
 package Net::Dict;
 
@@ -18,8 +16,8 @@ use IO::Socket;
 use Net::Cmd;
 use Carp;
 
-use vars qw(@ISA $VERSION $debug);
-$VERSION = sprintf("%d.%02d", q$Revision: 2.6 $ =~ /(\d+)\.(\d+)/);
+use vars qw(@ISA $debug);
+our $VERSION = '2.08';
 
 #-----------------------------------------------------------------------
 # Default values for arguments to new(). We also use this to
